==> vue-ueditor-wrap-3.0.0.tgz: package/README.md <==
<h1 align="center">vue-ueditor-wrap</h1
>

<p align="center">一个“包装”了 UEditor 的 Vue 组件，支持通过 v-model 来绑定富文本编辑器的内容。</p>

<p align="center">
  <a href="https://www.npmjs.com/package/vue-ueditor-wrap"><img src="https://img.shields.io/npm/v/vue-ueditor-wrap.svg?style=flat-square" alt="Version"></a>
  <a href="https://npmcharts.com/compare/vue-ueditor-wrap?minimal=true"><img src="https://img.shields.io/npm/dm/vue-ueditor-wrap.svg?style=flat-square" alt="Downloads"></a>
  <a href="https://www.jsdelivr.com/package/npm/vue-ueditor-wrap"><img src="https://data.jsdelivr.com/v1/package/npm/vue-ueditor-wrap/badge?style=flat-square" alt="jsdelivr"></a>
  <a href="https://www.jsdelivr.com/package/npm/vue-ueditor-wrap"><img src="http://img.badgesize.io/https://cdn.jsdelivr.net/npm/vue-ueditor-wrap@latest/lib/vue-ueditor-wrap.min.js?compression=gzip&style=flat-square&label=gzip%20size&color=#4fc08d" alt="size"></a>
  <a href="https://github.com/HaoChuan9421/vue-ueditor-wrap/issues"><img src="https://img.shields.io/github/issues-closed/haochuan9421/vue-ueditor-wrap.svg?style=flat-square" alt="Issues"></a>
  <a href="https://github.com/HaoChuan9421/vue-ueditor-wrap/blob/master/LICENSE"><img src="https://img.shields.io/npm/l/vue-ueditor-wrap.svg?style=flat-square" alt="License"></a>
</p>

<p align="center">
  🔥 <a href="https://hc199421.gitee.io/vue-ueditor-wrap">文档网站（国内）</a>
  &nbsp;
  🌈 <a href="https://haochuan9421.github.io/vue-ueditor-wrap">文档网站（GitHub）</a>
	&nbsp;
	🧭 <a href="https://github.com/HaoChuan9421/vue-ueditor-wrap/tree/2.x">Vue 2 项目请移步此处</a>
</p>

==> vue-ueditor-wrap-3.0.1.tgz: package/README.md <==
<h1 align="center">vue-ueditor-wrap</h1
>

<p align="center">一个“包装”了 UEditor 的 Vue 组件，支持通过 v-model 来绑定富文本编辑器的内容，让 UEditor 的使用简单到像 Input 框一样。</p>

<p align="center">
  <a href="https://www.npmjs.com/package/vue-ueditor-wrap"><img src="https://img.shields.io/npm/v/vue-ueditor-wrap.svg?style=flat-square" alt="Version"></a>
  <a href="https://npmcharts.com/compare/vue-ueditor-wrap?minimal=true"><img src="https://img.shields.io/npm/dm/vue-ueditor-wrap.svg?style=flat-square" alt="Downloads"></a>
  <a href="https://www.jsdelivr.com/package/npm/vue-ueditor-wrap"><img src="https://data.jsdelivr.com/v1/package/npm/vue-ueditor-wrap/badge?style=flat-square" alt="jsdelivr"></a>
  <a href="https://www.jsdelivr.com/package/npm/vue-ueditor-wrap"><img src="http://img.badgesize.io/https://cdn.jsdelivr.net/npm/vue-ueditor-wrap@latest/lib/vue-ueditor-wrap.min.js?compression=gzip&style=flat-square&label=gzip%20size&color=#4fc08d" alt="size"></a>
  <a href="https://github.com/HaoChuan9421/vue-ueditor-wrap/issues"><img src="https://img.shields.io/github/issues-closed/haochuan9421/vue-ueditor-wrap.svg?style=flat-square" alt="Issues"></a>
  <a href="https://github.com/HaoChuan9421/vue-ueditor-wrap/blob/master/LICENSE"><img src="https://img.shields.io/npm/l/vue-ueditor-wrap.svg?style=flat-square" alt="License"></a>
</p>

<p align="center">
  🔥 <a href="https://hc199421.gitee.io/vue-ueditor-wrap" target="_blank" rel="noopener noreferrer">文档网站（国内）</a>
  &nbsp;
  🌈 <a href="https://haochuan9421.github.io/vue-ueditor-wrap" target="_blank" rel="noopener noreferrer">文档网站（GitHub）</a>
	&nbsp;
	🧭 <a href="https://github.com/HaoChuan9421/vue-ueditor-wrap/tree/2.x" target="_blank" rel="noopener noreferrer">Vue 2 项目请移步此处</a>
</p>
